# Overview
This package contains functions to simplify common tasks one might perform when interacting with The Cancer Imaging Archive (TCIA) via Jupyter/Python.
Learn more about TCIA and its open-access datasets at https://www.cancerimagingarchive.net/.

# Installation
```
pip install tcia_utils
```

# Usage
To import functions related to the NBIA software that holds TCIA's DICOM data:
```
from tcia_utils import nbia
```
Examples notebooks demonstrating tcia_utils functionality can be found at https://github.com/kirbyju/TCIA_Notebooks.
